"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AuthReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AuthReq = AuthReq

@typing_extensions.final
class AuthResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AuthResp = AuthResp

@typing_extensions.final
class FrameOption(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    IS_ACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    vega_id: builtins.int
    """"""
    req_id: builtins.str
    """"""
    sequence: builtins.int
    """"""
    is_ack: builtins.bool
    """"""
    @property
    def status(self) -> bilireq.grpc.protos.bilibili.rpc.status_pb2.Status:
        """"""
    ack_origin: builtins.str
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        vega_id: builtins.int = ...,
        req_id: builtins.str = ...,
        sequence: builtins.int = ...,
        is_ack: builtins.bool = ...,
        status: bilibili.rpc.status_pb2.Status | None = ...,
        ack_origin: builtins.str = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_origin", b"ack_origin", "is_ack", b"is_ack", "mid", b"mid", "req_id", b"req_id", "sequence", b"sequence", "status", b"status", "vega_id", b"vega_id"]) -> None: ...

global___FrameOption = FrameOption

@typing_extensions.final
class HeartbeatReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartbeatReq = HeartbeatReq

@typing_extensions.final
class HeartbeatResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartbeatResp = HeartbeatResp

@typing_extensions.final
class MessageAckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    vega_id: builtins.str
    """"""
    req_id: builtins.str
    """"""
    origin: builtins.str
    """"""
    target_path: builtins.str
    """"""
    def __init__(
        self,
        *,
        vega_id: builtins.str = ...,
        req_id: builtins.str = ...,
        origin: builtins.str = ...,
        target_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["origin", b"origin", "req_id", b"req_id", "target_path", b"target_path", "vega_id", b"vega_id"]) -> None: ...

global___MessageAckReq = MessageAckReq

@typing_extensions.final
class SubscribeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_PATHS_FIELD_NUMBER: builtins.int
    @property
    def target_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetPath]:
        """"""
    def __init__(
        self,
        *,
        target_paths: collections.abc.Iterable[global___TargetPath] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_paths", b"target_paths"]) -> None: ...

global___SubscribeReq = SubscribeReq

@typing_extensions.final
class TargetPath(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    SUBS_FIELD_NUMBER: builtins.int
    key: builtins.str
    """"""
    @property
    def subs(self) -> google.protobuf.any_pb2.Any:
        """"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        subs: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subs", b"subs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "subs", b"subs"]) -> None: ...

global___TargetPath = TargetPath

@typing_extensions.final
class VegaFrame(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    ROUTE_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    SUB_BIZ_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___FrameOption:
        """"""
    route_path: builtins.str
    """"""
    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
    @property
    def sub_biz(self) -> google.protobuf.any_pb2.Any:
        """"""
    def __init__(
        self,
        *,
        options: global___FrameOption | None = ...,
        route_path: builtins.str = ...,
        body: google.protobuf.any_pb2.Any | None = ...,
        sub_biz: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body", "options", b"options", "sub_biz", b"sub_biz"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "options", b"options", "route_path", b"route_path", "sub_biz", b"sub_biz"]) -> None: ...

global___VegaFrame = VegaFrame



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.gaia.gw import gw_api_pb2 as bilibili_dot_gaia_dot_gw_dot_gw__api__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class GaiaStub(object):
    """应用列表上报
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExUploadAppList = channel.unary_unary(
                '/bilibili.gaia.gw.Gaia/ExUploadAppList',
                request_serializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.GaiaEncryptMsgReq.SerializeToString,
                response_deserializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.UploadAppListReply.FromString,
                )
        self.ExFetchPublicKey = channel.unary_unary(
                '/bilibili.gaia.gw.Gaia/ExFetchPublicKey',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.FetchPublicKeyReply.FromString,
                )


class GaiaServicer(object):
    """应用列表上报
    """

    def ExUploadAppList(self, request, context):
        """应用列表上报
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExFetchPublicKey(self, request, context):
        """拉取rsa公钥
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GaiaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExUploadAppList': grpc.unary_unary_rpc_method_handler(
                    servicer.ExUploadAppList,
                    request_deserializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.GaiaEncryptMsgReq.FromString,
                    response_serializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.UploadAppListReply.SerializeToString,
            ),
            'ExFetchPublicKey': grpc.unary_unary_rpc_method_handler(
                    servicer.ExFetchPublicKey,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.FetchPublicKeyReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.gaia.gw.Gaia', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Gaia(object):
    """应用列表上报
    """

    @staticmethod
    def ExUploadAppList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.gaia.gw.Gaia/ExUploadAppList',
            bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.GaiaEncryptMsgReq.SerializeToString,
            bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.UploadAppListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExFetchPublicKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.gaia.gw.Gaia/ExFetchPublicKey',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bilibili_dot_gaia_dot_gw_dot_gw__api__pb2.FetchPublicKeyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PrivacyConfigState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PrivacyConfigStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivacyConfigState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    close: _PrivacyConfigState.ValueType  # 0
    """关闭"""
    open: _PrivacyConfigState.ValueType  # 1
    """打开"""

class PrivacyConfigState(_PrivacyConfigState, metaclass=_PrivacyConfigStateEnumTypeWrapper):
    """隐私开关状态"""

close: PrivacyConfigState.ValueType  # 0
"""关闭"""
open: PrivacyConfigState.ValueType  # 1
"""打开"""
global___PrivacyConfigState = PrivacyConfigState

class _PrivacyConfigType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PrivacyConfigTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivacyConfigType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    none: _PrivacyConfigType.ValueType  # 0
    """"""
    dynamic_city: _PrivacyConfigType.ValueType  # 1
    """动态同城"""

class PrivacyConfigType(_PrivacyConfigType, metaclass=_PrivacyConfigTypeEnumTypeWrapper):
    """隐私开关类型"""

none: PrivacyConfigType.ValueType  # 0
""""""
dynamic_city: PrivacyConfigType.ValueType  # 1
"""动态同城"""
global___PrivacyConfigType = PrivacyConfigType

@typing_extensions.final
class NoArgRequest(google.protobuf.message.Message):
    """空请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoArgRequest = NoArgRequest

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class PrivacyConfigItem(google.protobuf.message.Message):
    """隐私设置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVACY_CONFIG_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_URI_FIELD_NUMBER: builtins.int
    privacy_config_type: global___PrivacyConfigType.ValueType
    """隐私开关类型"""
    title: builtins.str
    """"""
    state: global___PrivacyConfigState.ValueType
    """隐私开关状态"""
    sub_title: builtins.str
    """"""
    sub_title_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        privacy_config_type: global___PrivacyConfigType.ValueType = ...,
        title: builtins.str = ...,
        state: global___PrivacyConfigState.ValueType = ...,
        sub_title: builtins.str = ...,
        sub_title_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_type", b"privacy_config_type", "state", b"state", "sub_title", b"sub_title", "sub_title_uri", b"sub_title_uri", "title", b"title"]) -> None: ...

global___PrivacyConfigItem = PrivacyConfigItem

@typing_extensions.final
class PrivacyConfigReply(google.protobuf.message.Message):
    """获取隐私设置-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVACY_CONFIG_ITEM_FIELD_NUMBER: builtins.int
    @property
    def privacy_config_item(self) -> global___PrivacyConfigItem:
        """隐私设置"""
    def __init__(
        self,
        *,
        privacy_config_item: global___PrivacyConfigItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["privacy_config_item", b"privacy_config_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_item", b"privacy_config_item"]) -> None: ...

global___PrivacyConfigReply = PrivacyConfigReply

@typing_extensions.final
class SetPrivacyConfigRequest(google.protobuf.message.Message):
    """修改隐私设置-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVACY_CONFIG_TYPE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    privacy_config_type: global___PrivacyConfigType.ValueType
    """隐私开关类型"""
    state: global___PrivacyConfigState.ValueType
    """隐私开关状态"""
    def __init__(
        self,
        *,
        privacy_config_type: global___PrivacyConfigType.ValueType = ...,
        state: global___PrivacyConfigState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy_config_type", b"privacy_config_type", "state", b"state"]) -> None: ...

global___SetPrivacyConfigRequest = SetPrivacyConfigRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LinkType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LinkTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LinkType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LINK_TYPE_UNKNOWN: _LinkType.ValueType  # 0
    """未知"""
    LINK_TYPE_BANGUMI: _LinkType.ValueType  # 1
    """番剧"""
    LINK_TYPE_VIDEO: _LinkType.ValueType  # 2
    """视频"""
    LINK_TYPE_LIVE: _LinkType.ValueType  # 3
    """直播"""

class LinkType(_LinkType, metaclass=_LinkTypeEnumTypeWrapper):
    """"""

LINK_TYPE_UNKNOWN: LinkType.ValueType  # 0
"""未知"""
LINK_TYPE_BANGUMI: LinkType.ValueType  # 1
"""番剧"""
LINK_TYPE_VIDEO: LinkType.ValueType  # 2
"""视频"""
LINK_TYPE_LIVE: LinkType.ValueType  # 3
"""直播"""
global___LinkType = LinkType

@typing_extensions.final
class PageBlackList(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PageBlackList = PageBlackList

@typing_extensions.final
class PageView(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PageView = PageView

@typing_extensions.final
class PushMessageResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Biz:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BizEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PushMessageResp._Biz.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BIZ_UNKNOWN: PushMessageResp._Biz.ValueType  # 0
        """未知"""
        BIZ_VIDEO: PushMessageResp._Biz.ValueType  # 1
        """视频"""
        BIZ_LIVE: PushMessageResp._Biz.ValueType  # 2
        """直播"""
        BIZ_ACTIVITY: PushMessageResp._Biz.ValueType  # 3
        """活动"""

    class Biz(_Biz, metaclass=_BizEnumTypeWrapper):
        """业务类型"""

    BIZ_UNKNOWN: PushMessageResp.Biz.ValueType  # 0
    """未知"""
    BIZ_VIDEO: PushMessageResp.Biz.ValueType  # 1
    """视频"""
    BIZ_LIVE: PushMessageResp.Biz.ValueType  # 2
    """直播"""
    BIZ_ACTIVITY: PushMessageResp.Biz.ValueType  # 3
    """活动"""

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PushMessageResp._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNKNOWN: PushMessageResp._Type.ValueType  # 0
        """未知"""
        TYPE_DEFAULT: PushMessageResp._Type.ValueType  # 1
        """默认"""
        TYPE_HOT: PushMessageResp._Type.ValueType  # 2
        """热门"""
        TYPE_REALTIME: PushMessageResp._Type.ValueType  # 3
        """实时"""
        TYPE_RECOMMEND: PushMessageResp._Type.ValueType  # 4
        """推荐"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """消息类型"""

    TYPE_UNKNOWN: PushMessageResp.Type.ValueType  # 0
    """未知"""
    TYPE_DEFAULT: PushMessageResp.Type.ValueType  # 1
    """默认"""
    TYPE_HOT: PushMessageResp.Type.ValueType  # 2
    """热门"""
    TYPE_REALTIME: PushMessageResp.Type.ValueType  # 3
    """实时"""
    TYPE_RECOMMEND: PushMessageResp.Type.ValueType  # 4
    """推荐"""

    class _Position:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PositionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PushMessageResp._Position.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POS_UNKNOWN: PushMessageResp._Position.ValueType  # 0
        """未知"""
        POS_TOP: PushMessageResp._Position.ValueType  # 1
        """顶部"""

    class Position(_Position, metaclass=_PositionEnumTypeWrapper):
        """展示未知"""

    POS_UNKNOWN: PushMessageResp.Position.ValueType  # 0
    """未知"""
    POS_TOP: PushMessageResp.Position.ValueType  # 1
    """顶部"""

    OLD_TASKID_FIELD_NUMBER: builtins.int
    BIZ_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    TASKID_FIELD_NUMBER: builtins.int
    PAGE_BLACKLIST_FIELD_NUMBER: builtins.int
    PAGE_VIEW_FIELD_NUMBER: builtins.int
    TARGET_RESOURCE_FIELD_NUMBER: builtins.int
    IMAGE_FRAME_FIELD_NUMBER: builtins.int
    IMAGE_MARKER_FIELD_NUMBER: builtins.int
    IMAGE_POSITION_FIELD_NUMBER: builtins.int
    JOB_FIELD_NUMBER: builtins.int
    old_taskid: builtins.int
    """Deprecated: 推送任务id，使用string"""
    biz: global___PushMessageResp.Biz.ValueType
    """业务
    1:是视频 2:是直播 3:是活动
    """
    type: global___PushMessageResp.Type.ValueType
    """类型
    1:是默认 2:是热门 3:是实时 4:是推荐
    """
    title: builtins.str
    """主标题"""
    summary: builtins.str
    """副标题"""
    img: builtins.str
    """图片地址"""
    link: builtins.str
    """跳转地址"""
    position: global___PushMessageResp.Position.ValueType
    """展示位置，1是顶部"""
    duration: builtins.int
    """展示时长（单位：秒），默认3秒"""
    expire: builtins.int
    """失效时间"""
    taskid: builtins.str
    """推送任务id"""
    @property
    def page_blackList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PageBlackList]:
        """应用内推送黑名单
        UGC:     ugc-video-detail
        PGC:     pgc-video-detail
        一起看:   pgc-video-detail-theater
        直播:     live-room-detail
        Story:    ugc-video-detail-vertical
        播单黑名单 playlist-video-detail
        """
    @property
    def page_view(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PageView]:
        """预留pvid"""
    @property
    def target_resource(self) -> global___TargetResource:
        """跳转资源"""
    image_frame: builtins.int
    """"""
    image_marker: builtins.int
    """"""
    image_position: builtins.int
    """"""
    job: builtins.int
    """"""
    def __init__(
        self,
        *,
        old_taskid: builtins.int = ...,
        biz: global___PushMessageResp.Biz.ValueType = ...,
        type: global___PushMessageResp.Type.ValueType = ...,
        title: builtins.str = ...,
        summary: builtins.str = ...,
        img: builtins.str = ...,
        link: builtins.str = ...,
        position: global___PushMessageResp.Position.ValueType = ...,
        duration: builtins.int = ...,
        expire: builtins.int = ...,
        taskid: builtins.str = ...,
        page_blackList: collections.abc.Iterable[global___PageBlackList] | None = ...,
        page_view: collections.abc.Iterable[global___PageView] | None = ...,
        target_resource: global___TargetResource | None = ...,
        image_frame: builtins.int = ...,
        image_marker: builtins.int = ...,
        image_position: builtins.int = ...,
        job: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["target_resource", b"target_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz", b"biz", "duration", b"duration", "expire", b"expire", "image_frame", b"image_frame", "image_marker", b"image_marker", "image_position", b"image_position", "img", b"img", "job", b"job", "link", b"link", "old_taskid", b"old_taskid", "page_blackList", b"page_blackList", "page_view", b"page_view", "position", b"position", "summary", b"summary", "target_resource", b"target_resource", "taskid", b"taskid", "title", b"title", "type", b"type"]) -> None: ...

global___PushMessageResp = PushMessageResp

@typing_extensions.final
class TargetResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    Type: global___LinkType.ValueType
    """直播:   roomid
    UGC:   avid
    PGC:   seasonid
    Story: avid
    举个例子
    Type: LINK_TYPE_BANGUMI (番剧)
    Resource: {"seasonid":"123"}

    Type: LINK_TYPE_VIDEO (视频)
    Resource: {"avid":"123"}

    Type: LINK_TYPE_LIVE (直播)
    Resource: {"roomid":"123"}
    """
    @property
    def Resource(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        Type: global___LinkType.ValueType = ...,
        Resource: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Resource", b"Resource", "Type", b"Type"]) -> None: ...

global___TargetResource = TargetResource



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DefaultWordsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRACKID_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    WORD_FIELD_NUMBER: builtins.int
    SHOW_FRONT_FIELD_NUMBER: builtins.int
    EXP_STR_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    trackid: builtins.str
    """"""
    param: builtins.str
    """"""
    show: builtins.str
    """"""
    word: builtins.str
    """"""
    show_front: builtins.int
    """"""
    exp_str: builtins.str
    """"""
    goto: builtins.str
    """"""
    value: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        trackid: builtins.str = ...,
        param: builtins.str = ...,
        show: builtins.str = ...,
        word: builtins.str = ...,
        show_front: builtins.int = ...,
        exp_str: builtins.str = ...,
        goto: builtins.str = ...,
        value: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exp_str", b"exp_str", "goto", b"goto", "param", b"param", "show", b"show", "show_front", b"show_front", "trackid", b"trackid", "uri", b"uri", "value", b"value", "word", b"word"]) -> None: ...

global___DefaultWordsReply = DefaultWordsReply

@typing_extensions.final
class NftFaceIcon(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SHOW_STATUS_FIELD_NUMBER: builtins.int
    region_type: builtins.int
    """"""
    icon: builtins.str
    """"""
    show_status: builtins.int
    """"""
    def __init__(
        self,
        *,
        region_type: builtins.int = ...,
        icon: builtins.str = ...,
        show_status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "region_type", b"region_type", "show_status", b"show_status"]) -> None: ...

global___NftFaceIcon = NftFaceIcon

@typing_extensions.final
class DefaultWordsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    LOGIN_EVENT_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    AN_FIELD_NUMBER: builtins.int
    IS_FRESH_FIELD_NUMBER: builtins.int
    login_event: builtins.int
    """"""
    teenagers_mode: builtins.int
    """"""
    lessons_mode: builtins.int
    """"""
    tab: builtins.str
    """"""
    event_id: builtins.str
    """"""
    avid: builtins.str
    """"""
    query: builtins.str
    """"""
    an: builtins.int
    """"""
    is_fresh: builtins.int
    """"""
    def __init__(
        self,
        *,
        login_event: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
        tab: builtins.str = ...,
        event_id: builtins.str = ...,
        avid: builtins.str = ...,
        query: builtins.str = ...,
        an: builtins.int = ...,
        is_fresh: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["an", b"an", "avid", b"avid", "event_id", b"event_id", "from", b"from", "is_fresh", b"is_fresh", "lessons_mode", b"lessons_mode", "login_event", b"login_event", "query", b"query", "tab", b"tab", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___DefaultWordsReq = DefaultWordsReq

@typing_extensions.final
class SuggestionResult3Reply(google.protobuf.message.Message):
    """获取搜索建议-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRACKID_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    EXP_STR_FIELD_NUMBER: builtins.int
    trackid: builtins.str
    """搜索追踪id"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResultItem]:
        """搜索建议条目列表"""
    exp_str: builtins.str
    """搜索的abtest 实验信息"""
    def __init__(
        self,
        *,
        trackid: builtins.str = ...,
        list: collections.abc.Iterable[global___ResultItem] | None = ...,
        exp_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exp_str", b"exp_str", "list", b"list", "trackid", b"trackid"]) -> None: ...

global___SuggestionResult3Reply = SuggestionResult3Reply

@typing_extensions.final
class SuggestionResult3Req(google.protobuf.message.Message):
    """获取搜索建议-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    HIGHLIGHT_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """关键字"""
    highlight: builtins.int
    """是否语法高亮
    0:不显示 1:显示
    """
    teenagers_mode: builtins.int
    """是否青少年模式
    1:开启青少年模式
    """
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        highlight: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["highlight", b"highlight", "keyword", b"keyword", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___SuggestionResult3Req = SuggestionResult3Req

@typing_extensions.final
class ResultItem(google.protobuf.message.Message):
    """搜索建议条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVER_SIZE_FIELD_NUMBER: builtins.int
    SUG_TYPE_FIELD_NUMBER: builtins.int
    TERM_TYPE_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    ARCHIVES_FIELD_NUMBER: builtins.int
    PTIME_FIELD_NUMBER: builtins.int
    SEASON_TYPE_NAME_FIELD_NUMBER: builtins.int
    AREA_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    STYLES_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    LIVE_LINK_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    NFT_FACE_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """显示结果(语法高亮)"""
    keyword: builtins.str
    """搜索关键字"""
    position: builtins.int
    """序号"""
    cover: builtins.str
    """图片"""
    cover_size: builtins.float
    """图片尺寸"""
    sug_type: builtins.str
    """sug词类型"""
    term_type: builtins.int
    """词条大类型"""
    goto: builtins.str
    """跳转类型"""
    uri: builtins.str
    """跳转uri"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """认证信息"""
    param: builtins.str
    """跳转参数"""
    mid: builtins.int
    """up主mid"""
    fans: builtins.int
    """粉丝数"""
    level: builtins.int
    """up主等级"""
    archives: builtins.int
    """up主稿件数"""
    ptime: builtins.int
    """投稿时间"""
    season_type_name: builtins.str
    """season类型名称"""
    area: builtins.str
    """地区"""
    style: builtins.str
    """作品风格"""
    label: builtins.str
    """描述信息"""
    rating: builtins.float
    """评分"""
    vote: builtins.int
    """投票数"""
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReasonStyle]:
        """角标"""
    styles: builtins.str
    """"""
    module_id: builtins.int
    """"""
    live_link: builtins.str
    """"""
    face_nft_new: builtins.int
    """"""
    @property
    def nft_face_icon(self) -> global___NftFaceIcon:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        keyword: builtins.str = ...,
        position: builtins.int = ...,
        cover: builtins.str = ...,
        cover_size: builtins.float = ...,
        sug_type: builtins.str = ...,
        term_type: builtins.int = ...,
        goto: builtins.str = ...,
        uri: builtins.str = ...,
        official_verify: global___OfficialVerify | None = ...,
        param: builtins.str = ...,
        mid: builtins.int = ...,
        fans: builtins.int = ...,
        level: builtins.int = ...,
        archives: builtins.int = ...,
        ptime: builtins.int = ...,
        season_type_name: builtins.str = ...,
        area: builtins.str = ...,
        style: builtins.str = ...,
        label: builtins.str = ...,
        rating: builtins.float = ...,
        vote: builtins.int = ...,
        badges: collections.abc.Iterable[global___ReasonStyle] | None = ...,
        styles: builtins.str = ...,
        module_id: builtins.int = ...,
        live_link: builtins.str = ...,
        face_nft_new: builtins.int = ...,
        nft_face_icon: global___NftFaceIcon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["nft_face_icon", b"nft_face_icon", "official_verify", b"official_verify"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archives", b"archives", "area", b"area", "badges", b"badges", "cover", b"cover", "cover_size", b"cover_size", "face_nft_new", b"face_nft_new", "fans", b"fans", "from", b"from", "goto", b"goto", "keyword", b"keyword", "label", b"label", "level", b"level", "live_link", b"live_link", "mid", b"mid", "module_id", b"module_id", "nft_face_icon", b"nft_face_icon", "official_verify", b"official_verify", "param", b"param", "position", b"position", "ptime", b"ptime", "rating", b"rating", "season_type_name", b"season_type_name", "style", b"style", "styles", b"styles", "sug_type", b"sug_type", "term_type", b"term_type", "title", b"title", "uri", b"uri", "vote", b"vote"]) -> None: ...

global___ResultItem = ResultItem

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    127:未认证 0:个人 1:机构
    """
    desc: builtins.str
    """认证描述"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class ReasonStyle(google.protobuf.message.Message):
    """角标"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """角标文案"""
    text_color: builtins.str
    """文案日间色值"""
    text_color_night: builtins.str
    """文案夜间色值"""
    bg_color: builtins.str
    """背景日间色值"""
    bg_color_night: builtins.str
    """背景夜间色值"""
    border_color: builtins.str
    """边框日间色值"""
    border_color_night: builtins.str
    """边框夜间色值"""
    bg_style: builtins.int
    """角标样式
    1:填充模式 2:镂空模式
    """
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___ReasonStyle = ReasonStyle



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


class DynamicStub(object):
    """v2动态
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DynVideo = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideo',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.FromString,
                )
        self.DynAll = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAll',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.FromString,
                )
        self.DynDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.FromString,
                )
        self.DynVideoPersonal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideoPersonal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
                )
        self.DynVideoUpdOffset = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideoUpdOffset',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynAdditionCommonFollow = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAdditionCommonFollow',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.FromString,
                )
        self.DynThumb = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynThumb',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynFakeCard = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynFakeCard',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.FromString,
                )
        self.DynRcmdUpExchange = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynRcmdUpExchange',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.FromString,
                )
        self.DynAllPersonal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAllPersonal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.FromString,
                )
        self.DynAllUpdOffset = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAllUpdOffset',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynVote = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVote',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.FromString,
                )
        self.DynMixUpListViewMore = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynMixUpListViewMore',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
                )
        self.DynLight = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynLight',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.FromString,
                )
        self.DynDetail = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynDetail',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.FromString,
                )
        self.LikeList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/LikeList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.FromString,
                )
        self.RepostList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/RepostList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.FromString,
                )
        self.ReactionList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/ReactionList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.FromString,
                )
        self.DynSpace = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSpace',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.FromString,
                )
        self.DynUnLoginRcmd = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynUnLoginRcmd',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.FromString,
                )
        self.DynServerDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynServerDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.FromString,
                )
        self.DynSearch = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSearch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.FromString,
                )
        self.SetDecision = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SetDecision',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.AlumniDynamics = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/AlumniDynamics',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.FromString,
                )
        self.CampusRcmd = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRcmd',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.FromString,
                )
        self.SubscribeCampus = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SubscribeCampus',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.SetRecentCampus = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SetRecentCampus',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynTab = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynTab',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.FromString,
                )
        self.SchoolSearch = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SchoolSearch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.FromString,
                )
        self.SchoolRecommend = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SchoolRecommend',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.FromString,
                )
        self.DynSpaceSearchDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSpaceSearchDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.FromString,
                )
        self.OfficialAccounts = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/OfficialAccounts',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.FromString,
                )
        self.OfficialDynamics = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/OfficialDynamics',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.FromString,
                )
        self.CampusRedDot = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRedDot',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.FromString,
                )
        self.CampusRcmdFeed = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRcmdFeed',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.FromString,
                )
        self.TopicSquare = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/TopicSquare',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.FromString,
                )
        self.TopicList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/TopicList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.FromString,
                )
        self.CampusMateLikeList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusMateLikeList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.FromString,
                )
        self.CampusFeedback = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusFeedback',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.FromString,
                )
        self.CampusBillboard = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusBillboard',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
                )
        self.CampusBillboardInternal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusBillboardInternal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
                )
        self.CampusTopicRcmdFeed = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusTopicRcmdFeed',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.FromString,
                )


class DynamicServicer(object):
    """v2动态
    """

    def DynVideo(self, request, context):
        """动态视频页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAll(self, request, context):
        """动态综合页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynDetails(self, request, context):
        """批量动态id获取动态详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVideoPersonal(self, request, context):
        """视频页最近访问 - 个人feed流
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVideoUpdOffset(self, request, context):
        """视频页最近访问 - 标记已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAdditionCommonFollow(self, request, context):
        """动态通用附加卡-follow/取消follow
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynThumb(self, request, context):
        """动态点赞
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynFakeCard(self, request, context):
        """动态发布生成临时卡
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynRcmdUpExchange(self, request, context):
        """关注推荐up主换一换
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAllPersonal(self, request, context):
        """综合页最近访问 - 个人feed流
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAllUpdOffset(self, request, context):
        """综合页最近访问 - 标记已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVote(self, request, context):
        """投票操作接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynMixUpListViewMore(self, request, context):
        """网关调用 - 查看更多-列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynLight(self, request, context):
        """轻浏览
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynDetail(self, request, context):
        """动态详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LikeList(self, request, context):
        """点赞列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RepostList(self, request, context):
        """转发列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReactionList(self, request, context):
        """新版动态转发点赞列表 需要登录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSpace(self, request, context):
        """空间页动态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynUnLoginRcmd(self, request, context):
        """未登录页分区UP主推荐
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynServerDetails(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSearch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDecision(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlumniDynamics(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRcmd(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeCampus(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRecentCampus(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynTab(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchoolSearch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchoolRecommend(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSpaceSearchDetails(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OfficialAccounts(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OfficialDynamics(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRedDot(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRcmdFeed(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TopicSquare(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TopicList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusMateLikeList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusFeedback(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusBillboard(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusBillboardInternal(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusTopicRcmdFeed(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DynamicServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DynVideo': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideo,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.SerializeToString,
            ),
            'DynAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAll,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.SerializeToString,
            ),
            'DynDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.SerializeToString,
            ),
            'DynVideoPersonal': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideoPersonal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.SerializeToString,
            ),
            'DynVideoUpdOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideoUpdOffset,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynAdditionCommonFollow': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAdditionCommonFollow,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.SerializeToString,
            ),
            'DynThumb': grpc.unary_unary_rpc_method_handler(
                    servicer.DynThumb,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynFakeCard': grpc.unary_unary_rpc_method_handler(
                    servicer.DynFakeCard,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.SerializeToString,
            ),
            'DynRcmdUpExchange': grpc.unary_unary_rpc_method_handler(
                    servicer.DynRcmdUpExchange,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.SerializeToString,
            ),
            'DynAllPersonal': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAllPersonal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.SerializeToString,
            ),
            'DynAllUpdOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAllUpdOffset,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynVote': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVote,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.SerializeToString,
            ),
            'DynMixUpListViewMore': grpc.unary_unary_rpc_method_handler(
                    servicer.DynMixUpListViewMore,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.SerializeToString,
            ),
            'DynLight': grpc.unary_unary_rpc_method_handler(
                    servicer.DynLight,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.SerializeToString,
            ),
            'DynDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.DynDetail,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.SerializeToString,
            ),
            'LikeList': grpc.unary_unary_rpc_method_handler(
                    servicer.LikeList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.SerializeToString,
            ),
            'RepostList': grpc.unary_unary_rpc_method_handler(
                    servicer.RepostList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.SerializeToString,
            ),
            'ReactionList': grpc.unary_unary_rpc_method_handler(
                    servicer.ReactionList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.SerializeToString,
            ),
            'DynSpace': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSpace,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.SerializeToString,
            ),
            'DynUnLoginRcmd': grpc.unary_unary_rpc_method_handler(
                    servicer.DynUnLoginRcmd,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.SerializeToString,
            ),
            'DynServerDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynServerDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.SerializeToString,
            ),
            'DynSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSearch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.SerializeToString,
            ),
            'SetDecision': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDecision,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'AlumniDynamics': grpc.unary_unary_rpc_method_handler(
                    servicer.AlumniDynamics,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.SerializeToString,
            ),
            'CampusRcmd': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRcmd,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.SerializeToString,
            ),
            'SubscribeCampus': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeCampus,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'SetRecentCampus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRecentCampus,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynTab': grpc.unary_unary_rpc_method_handler(
                    servicer.DynTab,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.SerializeToString,
            ),
            'SchoolSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SchoolSearch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.SerializeToString,
            ),
            'SchoolRecommend': grpc.unary_unary_rpc_method_handler(
                    servicer.SchoolRecommend,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.SerializeToString,
            ),
            'DynSpaceSearchDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSpaceSearchDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.SerializeToString,
            ),
            'OfficialAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.OfficialAccounts,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.SerializeToString,
            ),
            'OfficialDynamics': grpc.unary_unary_rpc_method_handler(
                    servicer.OfficialDynamics,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.SerializeToString,
            ),
            'CampusRedDot': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRedDot,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.SerializeToString,
            ),
            'CampusRcmdFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRcmdFeed,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.SerializeToString,
            ),
            'TopicSquare': grpc.unary_unary_rpc_method_handler(
                    servicer.TopicSquare,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.SerializeToString,
            ),
            'TopicList': grpc.unary_unary_rpc_method_handler(
                    servicer.TopicList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.SerializeToString,
            ),
            'CampusMateLikeList': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusMateLikeList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.SerializeToString,
            ),
            'CampusFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusFeedback,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.SerializeToString,
            ),
            'CampusBillboard': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusBillboard,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.SerializeToString,
            ),
            'CampusBillboardInternal': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusBillboardInternal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.SerializeToString,
            ),
            'CampusTopicRcmdFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusTopicRcmdFeed,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.dynamic.v2.Dynamic', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Dynamic(object):
    """v2动态
    """

    @staticmethod
    def DynVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideo',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAll',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVideoPersonal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideoPersonal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVideoUpdOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideoUpdOffset',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAdditionCommonFollow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAdditionCommonFollow',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynThumb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynThumb',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynFakeCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynFakeCard',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynRcmdUpExchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynRcmdUpExchange',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAllPersonal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAllPersonal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAllUpdOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAllUpdOffset',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVote',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynMixUpListViewMore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynMixUpListViewMore',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynLight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynLight',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynDetail',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LikeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/LikeList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RepostList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/RepostList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReactionList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/ReactionList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSpace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSpace',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynUnLoginRcmd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynUnLoginRcmd',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynServerDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynServerDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSearch',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDecision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SetDecision',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlumniDynamics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/AlumniDynamics',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRcmd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRcmd',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeCampus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SubscribeCampus',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRecentCampus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SetRecentCampus',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynTab',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchoolSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SchoolSearch',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchoolRecommend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SchoolRecommend',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSpaceSearchDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSpaceSearchDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OfficialAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/OfficialAccounts',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OfficialDynamics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/OfficialDynamics',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRedDot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRedDot',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRcmdFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRcmdFeed',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TopicSquare(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/TopicSquare',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TopicList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/TopicList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusMateLikeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusMateLikeList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusFeedback',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusBillboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusBillboard',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusBillboardInternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusBillboardInternal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusTopicRcmdFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusTopicRcmdFeed',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HeartbeatReply(google.protobuf.message.Message):
    """客户端心跳上报-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TS_FIELD_NUMBER: builtins.int
    ts: builtins.int
    """时间戳"""
    def __init__(
        self,
        *,
        ts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ts", b"ts"]) -> None: ...

global___HeartbeatReply = HeartbeatReply

@typing_extensions.final
class HeartbeatReq(google.protobuf.message.Message):
    """客户端心跳上报-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_TIME_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    TOTAL_TIME_FIELD_NUMBER: builtins.int
    PAUSED_TIME_FIELD_NUMBER: builtins.int
    PLAYED_TIME_FIELD_NUMBER: builtins.int
    VIDEO_DURATION_FIELD_NUMBER: builtins.int
    PLAY_TYPE_FIELD_NUMBER: builtins.int
    NETWORK_TYPE_FIELD_NUMBER: builtins.int
    LAST_PLAY_PROGRESS_TIME_FIELD_NUMBER: builtins.int
    MAX_PLAY_PROGRESS_TIME_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    EPID_STATUS_FIELD_NUMBER: builtins.int
    PLAY_STATUS_FIELD_NUMBER: builtins.int
    USER_STATUS_FIELD_NUMBER: builtins.int
    ACTUAL_PLAYED_TIME_FIELD_NUMBER: builtins.int
    AUTO_PLAY_FIELD_NUMBER: builtins.int
    LIST_PLAY_TIME_FIELD_NUMBER: builtins.int
    DETAIL_PLAY_TIME_FIELD_NUMBER: builtins.int
    server_time: builtins.int
    """"""
    session: builtins.str
    """"""
    mid: builtins.int
    """用户 mid"""
    aid: builtins.int
    """稿件 avid"""
    cid: builtins.int
    """视频 cid"""
    sid: builtins.str
    """"""
    epid: builtins.int
    """"""
    type: builtins.str
    """"""
    sub_type: builtins.int
    """"""
    quality: builtins.int
    """"""
    total_time: builtins.int
    """"""
    paused_time: builtins.int
    """"""
    played_time: builtins.int
    """"""
    video_duration: builtins.int
    """"""
    play_type: builtins.str
    """"""
    network_type: builtins.int
    """"""
    last_play_progress_time: builtins.int
    """"""
    max_play_progress_time: builtins.int
    """"""
    from_spmid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    epid_status: builtins.str
    """"""
    play_status: builtins.str
    """"""
    user_status: builtins.str
    """"""
    actual_played_time: builtins.int
    """"""
    auto_play: builtins.int
    """"""
    list_play_time: builtins.int
    """"""
    detail_play_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        server_time: builtins.int = ...,
        session: builtins.str = ...,
        mid: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        sid: builtins.str = ...,
        epid: builtins.int = ...,
        type: builtins.str = ...,
        sub_type: builtins.int = ...,
        quality: builtins.int = ...,
        total_time: builtins.int = ...,
        paused_time: builtins.int = ...,
        played_time: builtins.int = ...,
        video_duration: builtins.int = ...,
        play_type: builtins.str = ...,
        network_type: builtins.int = ...,
        last_play_progress_time: builtins.int = ...,
        max_play_progress_time: builtins.int = ...,
        from_spmid: builtins.str = ...,
        spmid: builtins.str = ...,
        epid_status: builtins.str = ...,
        play_status: builtins.str = ...,
        user_status: builtins.str = ...,
        actual_played_time: builtins.int = ...,
        auto_play: builtins.int = ...,
        list_play_time: builtins.int = ...,
        detail_play_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actual_played_time", b"actual_played_time", "aid", b"aid", "auto_play", b"auto_play", "cid", b"cid", "detail_play_time", b"detail_play_time", "epid", b"epid", "epid_status", b"epid_status", "from", b"from", "from_spmid", b"from_spmid", "last_play_progress_time", b"last_play_progress_time", "list_play_time", b"list_play_time", "max_play_progress_time", b"max_play_progress_time", "mid", b"mid", "network_type", b"network_type", "paused_time", b"paused_time", "play_status", b"play_status", "play_type", b"play_type", "played_time", b"played_time", "quality", b"quality", "server_time", b"server_time", "session", b"session", "sid", b"sid", "spmid", b"spmid", "sub_type", b"sub_type", "total_time", b"total_time", "type", b"type", "user_status", b"user_status", "video_duration", b"video_duration"]) -> None: ...

global___HeartbeatReq = HeartbeatReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/playeronline/v1/playeronline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/app/playeronline/v1/playeronline.proto\x12\x1c\x62ilibili.app.playeronline.v1\"\t\n\x07NoReply\"\xa3\x01\n\x11PlayerOnlineReply\x12\x12\n\ntotal_text\x18\x01 \x01(\t\x12\x10\n\x08sec_next\x18\x02 \x01(\x03\x12\x13\n\x0b\x62ottom_show\x18\x03 \x01(\x08\x12\x10\n\x08sdm_show\x18\x04 \x01(\x08\x12\x10\n\x08sdm_text\x18\x05 \x01(\t\x12\x14\n\x0ctotal_number\x18\x06 \x01(\x03\x12\x19\n\x11total_number_text\x18\x07 \x01(\t\">\n\x0fPlayerOnlineReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x11\n\tplay_open\x18\x03 \x01(\x08\"Y\n\x11PremiereInfoReply\x12\x1a\n\x12premiere_over_text\x18\x01 \x01(\t\x12\x13\n\x0bparticipant\x18\x02 \x01(\x03\x12\x13\n\x0binteraction\x18\x03 \x01(\x03\"\x1e\n\x0fPremiereInfoReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\"9\n\x0eReportWatchReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x62iz\x18\x02 \x01(\t\x12\r\n\x05\x62uvid\x18\x03 \x01(\t2\xd2\x02\n\x0cPlayerOnline\x12n\n\x0cPlayerOnline\x12-.bilibili.app.playeronline.v1.PlayerOnlineReq\x1a/.bilibili.app.playeronline.v1.PlayerOnlineReply\x12n\n\x0cPremiereInfo\x12-.bilibili.app.playeronline.v1.PremiereInfoReq\x1a/.bilibili.app.playeronline.v1.PremiereInfoReply\x12\x62\n\x0bReportWatch\x12,.bilibili.app.playeronline.v1.ReportWatchReq\x1a%.bilibili.app.playeronline.v1.NoReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playeronline.v1.playeronline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOREPLY._serialized_start=81
  _NOREPLY._serialized_end=90
  _PLAYERONLINEREPLY._serialized_start=93
  _PLAYERONLINEREPLY._serialized_end=256
  _PLAYERONLINEREQ._serialized_start=258
  _PLAYERONLINEREQ._serialized_end=320
  _PREMIEREINFOREPLY._serialized_start=322
  _PREMIEREINFOREPLY._serialized_end=411
  _PREMIEREINFOREQ._serialized_start=413
  _PREMIEREINFOREQ._serialized_end=443
  _REPORTWATCHREQ._serialized_start=445
  _REPORTWATCHREQ._serialized_end=502
  _PLAYERONLINE._serialized_start=505
  _PLAYERONLINE._serialized_end=843
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetStudioListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id", b"room_id"]) -> None: ...

global___GetStudioListReq = GetStudioListReq

@typing_extensions.final
class GetStudioListResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Pendants(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FRAME_FIELD_NUMBER: builtins.int
        BADGE_FIELD_NUMBER: builtins.int
        @property
        def frame(self) -> global___GetStudioListResp.Pendant:
            """"""
        @property
        def badge(self) -> global___GetStudioListResp.Pendant:
            """"""
        def __init__(
            self,
            *,
            frame: global___GetStudioListResp.Pendant | None = ...,
            badge: global___GetStudioListResp.Pendant | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "frame", b"frame"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "frame", b"frame"]) -> None: ...

    @typing_extensions.final
    class Pendant(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        POSITION_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        DESC_FIELD_NUMBER: builtins.int
        name: builtins.str
        """"""
        position: builtins.int
        """"""
        value: builtins.str
        """"""
        desc: builtins.str
        """"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            position: builtins.int = ...,
            value: builtins.str = ...,
            desc: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "name", b"name", "position", b"position", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StudioMaster(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UID_FIELD_NUMBER: builtins.int
        ROOM_ID_FIELD_NUMBER: builtins.int
        UNAME_FIELD_NUMBER: builtins.int
        FACE_FIELD_NUMBER: builtins.int
        PENDANTS_FIELD_NUMBER: builtins.int
        TAG_FIELD_NUMBER: builtins.int
        TAG_TYPE_FIELD_NUMBER: builtins.int
        uid: builtins.int
        """"""
        room_id: builtins.int
        """"""
        uname: builtins.str
        """"""
        face: builtins.str
        """"""
        @property
        def pendants(self) -> global___GetStudioListResp.Pendants:
            """"""
        tag: builtins.str
        """"""
        tag_type: builtins.int
        """"""
        def __init__(
            self,
            *,
            uid: builtins.int = ...,
            room_id: builtins.int = ...,
            uname: builtins.str = ...,
            face: builtins.str = ...,
            pendants: global___GetStudioListResp.Pendants | None = ...,
            tag: builtins.str = ...,
            tag_type: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["pendants", b"pendants"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "pendants", b"pendants", "room_id", b"room_id", "tag", b"tag", "tag_type", b"tag_type", "uid", b"uid", "uname", b"uname"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    MASTER_LIST_FIELD_NUMBER: builtins.int
    status: builtins.int
    """"""
    @property
    def master_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetStudioListResp.StudioMaster]:
        """"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        master_list: collections.abc.Iterable[global___GetStudioListResp.StudioMaster] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["master_list", b"master_list", "status", b"status"]) -> None: ...

global___GetStudioListResp = GetStudioListResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LiveStartEvent(google.protobuf.message.Message):
    """开播事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___LiveStartEvent = LiveStartEvent

@typing_extensions.final
class LiveEndEvent(google.protobuf.message.Message):
    """直播中止事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___LiveEndEvent = LiveEndEvent

@typing_extensions.final
class LiveOnlineEvent(google.protobuf.message.Message):
    """在线人数事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """在线人数"""
    def __init__(
        self,
        *,
        online: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online", b"online"]) -> None: ...

global___LiveOnlineEvent = LiveOnlineEvent

@typing_extensions.final
class LiveUpdateEvent(google.protobuf.message.Message):
    """变更通知"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFTER_PREMIERE_TYPE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    after_premiere_type: builtins.int
    """直播后状态
    1:下线 2:转点播
    """
    start_time: builtins.int
    """直播开始绝对时间 单位ms"""
    id: builtins.str
    """id"""
    progress: builtins.int
    """服务端播放进度，未打散，负数表示距离开播时间，正数表示已开播时间，单位：毫秒
    用户实际播放进度：progress - delay_time
    """
    def __init__(
        self,
        *,
        after_premiere_type: builtins.int = ...,
        start_time: builtins.int = ...,
        id: builtins.str = ...,
        progress: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_premiere_type", b"after_premiere_type", "id", b"id", "progress", b"progress", "start_time", b"start_time"]) -> None: ...

global___LiveUpdateEvent = LiveUpdateEvent

@typing_extensions.final
class CMDBody(google.protobuf.message.Message):
    """直播间事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    EMERGENCY_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> global___LiveStartEvent:
        """开播事件"""
    @property
    def emergency(self) -> global___LiveEndEvent:
        """直播中止事件"""
    @property
    def online(self) -> global___LiveOnlineEvent:
        """在线人数事件"""
    @property
    def update(self) -> global___LiveUpdateEvent:
        """变更通知"""
    def __init__(
        self,
        *,
        start: global___LiveStartEvent | None = ...,
        emergency: global___LiveEndEvent | None = ...,
        online: global___LiveOnlineEvent | None = ...,
        update: global___LiveUpdateEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["emergency", b"emergency", "event", b"event", "online", b"online", "start", b"start", "update", b"update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emergency", b"emergency", "event", b"event", "online", b"online", "start", b"start", "update", b"update"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["start", "emergency", "online", "update"] | None: ...

global___CMDBody = CMDBody



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/polymer/contract/contract.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/polymer/contract/contract.proto\x12\x19\x62ilibili.polymer.contract\x1a\x1bgoogle/protobuf/empty.proto\"g\n\x10\x41\x64\x64\x43ontractReply\x12\x15\n\rallow_message\x18\x01 \x01(\x08\x12\x13\n\x0b\x61llow_reply\x18\x02 \x01(\x08\x12\x12\n\ninput_text\x18\x03 \x01(\t\x12\x13\n\x0binput_title\x18\x04 \x01(\t\"\x80\x01\n\x0e\x41\x64\x64\x43ontractReq\x12\x34\n\x06\x63ommon\x18\x01 \x01(\x0b\x32$.bilibili.polymer.contract.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\"x\n\tCommonReq\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\r\n\x05spmid\x18\x07 \x01(\t\"0\n\x0c\x43ontractCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\"\x8b\x01\n\x13\x43ontractConfigReply\x12\x19\n\x11is_follow_display\x18\x01 \x01(\x05\x12\x19\n\x11is_triple_display\x18\x02 \x01(\x05\x12>\n\rcontract_card\x18\x03 \x01(\x0b\x32\'.bilibili.polymer.contract.ContractCard\"\x83\x01\n\x11\x43ontractConfigReq\x12\x34\n\x06\x63ommon\x18\x01 \x01(\x0b\x32$.bilibili.polymer.contract.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\x32\xb5\x02\n\x08\x43ontract\x12P\n\x0b\x41\x64\x64\x43ontract\x12).bilibili.polymer.contract.AddContractReq\x1a\x16.google.protobuf.Empty\x12g\n\rAddContractV2\x12).bilibili.polymer.contract.AddContractReq\x1a+.bilibili.polymer.contract.AddContractReply\x12n\n\x0e\x43ontractConfig\x12,.bilibili.polymer.contract.ContractConfigReq\x1a..bilibili.polymer.contract.ContractConfigReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.contract.contract_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDCONTRACTREPLY._serialized_start=100
  _ADDCONTRACTREPLY._serialized_end=203
  _ADDCONTRACTREQ._serialized_start=206
  _ADDCONTRACTREQ._serialized_end=334
  _COMMONREQ._serialized_start=336
  _COMMONREQ._serialized_end=456
  _CONTRACTCARD._serialized_start=458
  _CONTRACTCARD._serialized_end=506
  _CONTRACTCONFIGREPLY._serialized_start=509
  _CONTRACTCONFIGREPLY._serialized_end=648
  _CONTRACTCONFIGREQ._serialized_start=651
  _CONTRACTCONFIGREQ._serialized_end=782
  _CONTRACT._serialized_start=785
  _CONTRACT._serialized_end=1094
# @@protoc_insertion_point(module_scope)
